@@ -9,8 +9,8 @@ from .processing import (
     consolidate_values_for_sheet,
     read_geo,
     )
-from .download import run_series, run_series_list, convert_miniml
-
+from .download import run_series, run_series_list, convert_miniml, build_composite_dataset
+from .version import __version__
 
 getLogger(__name__).addHandler(NullHandler())
 
