@@ -236,6 +236,7 @@ def sample_sheet_from_miniml(geo_id, series_path, platform, samp_dict, meta_dict
     Notes:
         cleans up redundant columns, including Sample_Name == title and platform
             """
+
     # id and position are NOT in the miniml file, must match with GSMID later
     _dict = {'GSM_ID': [], 'Sample_Name': [], 'Sentrix_ID': [], 'Sentrix_Position': []}
     for GSM_ID, sample_title in samp_dict.items():
@@ -245,6 +246,7 @@ def sample_sheet_from_miniml(geo_id, series_path, platform, samp_dict, meta_dict
             if key not in _dict:
                 _dict[key] = []
             _dict[key].append(value)
+
     # arrays must be all same length
     out = _dict.copy()
     for column in _dict.keys():
@@ -261,14 +263,35 @@ def sample_sheet_from_miniml(geo_id, series_path, platform, samp_dict, meta_dict
                 if set(_dict[column]) == set(_dict[other_column]) and column != other_column:
                     LOGGER.debug(f"{column} == {other_column}; dropping {column}")
                     out.pop(column,None)
-
     try:
         df = pd.DataFrame(data=out)
     except ValueError as e: # arrays must all be same length
         from collections import Counter
         LOGGER.info(f"ValueError - array lengths vary in sample meta data: {[(key, len(val)) for key,val in out.items()]}")
-        ## would be HARD to salvage it by filling in blanks for missing rows ##
-        raise ValueError(f"{e}; this happens when a samplesheet is missing descriptors for one or more samples.")
+        LOGGER.info(f"Trying another method to save partial sample data into csv/pkl file.")
+        ## alt method to salvage it by filling in blanks for missing rows -- but doesn't seem to capture Sentrix_ID / Sentrix_Position ##
+        column_counts = {'GSM_ID': [], 'Sample_Name': []} # column_name : [GSM_IDs included]
+        out = {} # list of dicts as sample rows, keyed to GSM_IDs
+        for GSM_ID, sample_title in samp_dict.items():
+            out[GSM_ID] = {'GSM_ID': GSM_ID, 'Sample_Name': sample_title}
+            column_counts['GSM_ID'].append(GSM_ID)
+            column_counts['Sample_Name'].append(GSM_ID)
+            for key, value in meta_dict[GSM_ID].items():
+                out[GSM_ID][key] = value
+                if key not in column_counts:
+                    column_counts[key] = [GSM_ID]
+                else:
+                    column_counts[key].append(GSM_ID)
+        # check if any fields are missing GSM_IDs, and fill in with blanks
+        for col_name, gsm_id_list in column_counts.items():
+            if len(out) != len(gsm_id_list):
+                for GSM_ID in out.keys():
+                    if GSM_ID not in gsm_id_list:
+                        out[GSM_ID][col_name] = ''
+        try:
+            df = pd.DataFrame(data=list(out.values()))
+        except:
+            raise ValueError(f"{e}; this happens when a samplesheet is missing descriptors for one or more samples.")
     # filter: only retain control samples
     if extract_controls:
         keywords = ['control','ctrl']
@@ -372,36 +395,36 @@ def build_composite_dataset(geo_id_list, data_dir, merge=True, download_it=True,
     beta_values and/or m_values pkl files in one place, so that you can run `methylize.load_both()` to
     create a combined reference dataset for QC, analysis, or meta-analysis.
 
-Arguments:
-    geo_id_list (required):
-        A list of GEO "GSEnnn" ids. From command line, pass these in as separate values,
-    data_dir
+    Arguments:
+        geo_id_list (required):
+            A list of GEO "GSEnnn" ids. From command line, pass these in as separate values
+        data_dir:
+            folder to save data
+        merge (True):
+            If merge==True and there is a file with 'samplesheet' in the folder, and that sheet has GSM_IDs,
+            merge that data into this samplesheet. Useful for when you have idats and want one combined samplesheet for the dataset.
 
-    merge (True):
-        If merge==True and there is a file with 'samplesheet' in the folder, and that sheet has GSM_IDs,
-        merge that data into this samplesheet. Useful for when you have idats and want one combined samplesheet for the dataset.
+        download_it (True):
+            if miniml file not in data_dir path, it will download it from web.
 
-    download_it (True):
-        if miniml file not in data_dir path, it will download it from web.
+        extract_controls (True)):
+            if you only want to retain samples from the whole set that have certain keywords,
+            such as "control" or "blood", this experimental flag will rewrite the samplesheet with only the parts you want,
+            then feed that into run_pipeline with named samples.
+        require_keyword (None):
+            another way to eliminate samples from samplesheets, before passing into the processor.
+            if specified, the "keyword" string passed in must appear somewhere in the values of a samplesheet
+            for sample to be downloaded, processed, retained.
+        sync_idats:
+            If flagged, this will search `data_dir` for idats and remove any of those that are not found in the filtered samplesheet.
+            Requires you to run the download function first to get all idats, before you run this `meta_data` function.
+        betas:
+            process beta_values
+        m_value:
+            process m_values
 
-    extract_controls (True)):
-        if you only want to retain samples from the whole set that have certain keywords,
-        such as "control" or "blood", this experimental flag will rewrite the samplesheet with only the parts you want,
-        then feed that into run_pipeline with named samples.
-    require_keyword (None):
-        another way to eliminate samples from samplesheets, before passing into the processor.
-        if specified, the "keyword" string passed in must appear somewhere in the values of a samplesheet
-        for sample to be downloaded, processed, retained.
-    sync_idats:
-        If flagged, this will search `data_dir` for idats and remove any of those that are not found in the filtered samplesheet.
-        Requires you to run the download function first to get all idats, before you run this `meta_data` function.
-    betas:
-        process beta_values
-    m_value:
-        process m_values
-
-    - Attempts to also read idat filenames, if they exist, but won't fail if they don't.
-    - removes unneeded files as it goes, but leaves the xml MINiML file and folder there as a marker if a geo dataset fails to download. So it won't try again on resume.
+        - Attempts to also read idat filenames, if they exist, but won't fail if they don't.
+        - removes unneeded files as it goes, but leaves the xml MINiML file and folder there as a marker if a geo dataset fails to download. So it won't try again on resume.
     """
     def remove_unused_files(geo_id, geo_folder):
         if list(Path(data_dir, geo_id).rglob('*.idat')) == []:
